@@ -1,6 +1,6 @@
 package Date::Holidays::GB;
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 # ABSTRACT: Determine British holidays - Current UK public and bank holiday dates up to 2022
 
@@ -118,7 +118,7 @@ sub is_holiday {
         ( $y, $m, $d ) = $args{date} =~ m{^([0-9]{4})-([0-9]{2})-([0-9]{2})$};
     }
     else {
-        ( $y, $m, $d ) = @args{qw/ year month day /};
+        ( $y, $m, $d ) = @args{qw( year month day )};
     }
 
     die "Must specify either 'date' or 'year', 'month' and 'day'"
