@@ -1,6 +1,6 @@
 package Date::Holidays::GB::SCT;
 
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.018'; our $VERSION = '0.019'; # VERSION
 
 use strict;
 use warnings;
@@ -41,7 +41,7 @@ Date::Holidays::GB::SCT - Date::Holidays class for GB-SCT (Scotland)
 
 =head1 SYNOPSIS
 
-    use Date::Holidays::GB::SCT qw/ holidays is_holiday /;
+    use Date::Holidays::GB::SCT qw( holidays is_holiday );
 
     # All holidays for Scotland
     my $holidays = holidays( year => 2013 );
